Learn R Programming

RArcInfo (version 0.4-2)

avctoe00: Converts a ARC/INFO binary coverage into an ESRI E00 file

Description

This function makes a convertion to an ESRI E00 file from a binary coverage.

Usage

avctoe00(avcdir, e00file)

Arguments

avcdir
The path to the binary coverage we want to convert from.
e00file
The E00 file to be created.

Value

  • Returns 'NULL' on exit.

References

More information about this topic can be found at http://pages.infinit.net/danmo/e00/index-avce00.html.

See Also

e00toavc