get.tabledata: Function for importing the contents of a table file into R
Description
This function reads and imports into R the contents of a table file.
Usage
get.tabledata(infodir, tablename)
Arguments
infodir
Info directory where there is a file called arc.dat
tablename
The name of the table from which we want to import the data
Value
This function returns a data frame in which each column stores the
data of a field from the table. The columns are not assigned the names
of the fields, but this can be got with the get.tablefields function.
References
More information about this kind of data can be found at
http://pages.infinit.net/danmo/e00/docs/v7_bin_cover.html.