Directory under which all the coverages and a directory called 'info' are.
coverage
The name of the coverage we want to work with
filename
The name of the file in the coverage directory that
stores the data. By default, it is called 'pal.adf'
Value
This function returns a list with two elements. The first one is
a data frame with the next fields (columns):
PolygonIDA number that identifies this polygon.
MinXMinimum value for all the X component of the coordinates.
MinYMinimum value for all the Y component of the coordinates.
MaxXMaximum value for all the X component of the coordinates.
MaxYMaximum value for all the Y component of the coordinates.
NArcs
The second element in the list is also a list in which each element is
composed by three arrays with information about the polygons that
are in the polygon boundary: 'Arc ID', 'From Node' and 'Adjacent Polygon'.
References
More information about this kind of data can be found at
http://pages.infinit.net/danmo/e00/docs/v7_bin_cover.html.